@@ -1,5 +1,5 @@
 /*
-Copyright © 2020-2022 The k3d Author(s)
+Copyright © 2020-2023 The k3d Author(s)
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -26,7 +26,6 @@ import (
 	"context"
 	"fmt"
 	"io"
-	"os"
 
 	"github.com/docker/docker/api/types"
 	"github.com/docker/docker/api/types/container"
@@ -76,7 +75,7 @@ func startContainer(ctx context.Context, ID string) error {
 	}
 	defer docker.Close()
 
-	return docker.ContainerStart(ctx, ID, types.ContainerStartOptions{})
+	return docker.ContainerStart(ctx, ID, container.StartOptions{})
 }
 
 // removeContainer deletes a running container (like docker rm -f)
@@ -89,7 +88,7 @@ func removeContainer(ctx context.Context, ID string) error {
 	defer docker.Close()
 
 	// (1) define remove options
-	options := types.ContainerRemoveOptions{
+	options := container.RemoveOptions{
 		RemoveVolumes: true,
 		Force:         true,
 	}
@@ -117,7 +116,7 @@ func pullImage(ctx context.Context, docker client.APIClient, image string) error
 	// in debug mode (--verbose flag set), output pull progress
 	var writer io.Writer = io.Discard
 	if l.Log().GetLevel() == logrus.DebugLevel {
-		writer = os.Stdout
+		writer = l.Log().Out
 	}
 	_, err = io.Copy(writer, resp)
 	if err != nil {
@@ -147,7 +146,7 @@ func getNodeContainer(ctx context.Context, node *k3d.Node) (*types.Container, er
 	// -> user input may or may not have the "k3d-" prefix
 	filters.Add("name", fmt.Sprintf("^/?(%s-)?%s$", k3d.DefaultObjectNamePrefix, node.Name))
 
-	containers, err := docker.ContainerList(ctx, types.ContainerListOptions{
+	containers, err := docker.ContainerList(ctx, container.ListOptions{
 		Filters: filters,
 		All:     true,
 	})
